<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Niet alle agenda's zijn volledig gecached",
"Everything seems to be completely cached" => "Alles lijkt volledig gecached te zijn",
"No calendars found." => "Geen agenda's gevonden.",
"No events found." => "Geen gebeurtenissen gevonden.",
"Wrong calendar" => "Verkeerde agenda",
"You do not have the permissions to edit this event." => "U heeft geen permissie om deze gebeurtenis te bewerken.",
"The file contained either no events or all events are already saved in your calendar." => "Het bestand bevat geen gebeurtenissen of alle gebeurtenissen worden al in uw agenda bewaard.",
"events have been saved in the new calendar" => "afspraken zijn opgeslagen in de nieuwe agenda",
"Import failed" => "import is gefaald",
"events have been saved in your calendar" => "afspraken zijn opgeslagen in je agenda",
"New Timezone:" => "Nieuwe tijdszone:",
"Timezone changed" => "Tijdzone is veranderd",
"Invalid request" => "Ongeldige aanvraag",
"Calendar" => "Agenda",
"Deletion failed" => "Verwijderen mislukt",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "groep",
"can edit" => "kan wijzigen",
"can share" => "kan delen",
"ddd" => "ddd",
"ddd M/d" => "ddd d.M",
"dddd M/d" => "dddd d.M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, d. MMM yyyy",
"Sunday" => "Zondag",
"Monday" => "Maandag",
"Tuesday" => "Dinsdag",
"Wednesday" => "Woensdag",
"Thursday" => "Donderdag",
"Friday" => "Vrijdag",
"Saturday" => "Zaterdag",
"Sun." => "Zon.",
"Mon." => "Maa.",
"Tue." => "Din.",
"Wed." => "Woe.",
"Thu." => "Don.",
"Fri." => "Vrij.",
"Sat." => "Zat.",
"January" => "Januari",
"February" => "Februari",
"March" => "Maart",
"April" => "April",
"May" => "Mei",
"June" => "Juni",
"July" => "Juli",
"August" => "Augustus",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Maa.",
"Apr." => "Apr.",
"May." => "Mei.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Hele dag",
"New Calendar" => "Nieuwe agenda",
"Missing or invalid fields" => "Missende of ongeldige velden",
"Title" => "Titel",
"From Date" => "Begindatum",
"From Time" => "Begintijd",
"To Date" => "Einddatum",
"To Time" => "Eindtijd",
"The event ends before it starts" => "De gebeurtenis eindigt voor het begin",
"There was a database fail" => "Er was een databasefout",
"Interval is not valid. It must be a positive integer!" => "Interval is niet geldig. Het moet een positief, geheel getal zijn.",
"Birthday" => "Verjaardag",
"Business" => "Zakelijk",
"Call" => "Bellen",
"Clients" => "Klanten",
"Deliverer" => "Verantwoordelijke",
"Holidays" => "Vakantie",
"Ideas" => "Ideeën",
"Journey" => "Reis",
"Jubilee" => "Jubileum",
"Meeting" => "Vergadering",
"Other" => "Overig",
"Personal" => "Persoonlijk",
"Projects" => "Projecten",
"Questions" => "Vragen",
"Work" => "Werk",
"by" => "door",
"unnamed" => "onbekend",
"You do not have the permissions to update this calendar." => "U heeft geen permissie om deze agenda te bewerken.",
"You do not have the permissions to delete this calendar." => "U heeft geen permissie om deze agenda te verwijderen.",
"You do not have the permissions to add to this calendar." => "U heeft geen permissie om deze agenda toe te voegen.",
"You do not have the permissions to add events to this calendar." => "U heeft geen permissie om gebeurtenissen aan deze agenda toe te voegen.",
"You cannot add non-public events to a shared calendar." => "U kunt geen besloten afspraken in een gedeelde agenda opnemen.",
"You do not have the permissions to delete this event." => "U heeft geen permissie om deze gebeurtenis te verwijderen.",
"Busy" => "Bezig",
"Show full event" => "Toon gehele gebeurtenis",
"Show only busy" => "Toon alleen bezig",
"Hide event" => "Verberg gebeurtenis",
"Does not repeat" => "Geen",
"Daily" => "Dagelijks",
"Weekly" => "Wekelijks",
"Every Weekday" => "Elke weekdag",
"Bi-Weekly" => "Tweewekelijks",
"Monthly" => "Maandelijks",
"Yearly" => "Jaarlijks",
"never" => "geen",
"by occurrences" => "volgens gebeurtenissen",
"by date" => "op datum",
"by monthday" => "per dag van de maand",
"by weekday" => "op weekdag",
"events week of month" => "gebeurtenissen week van maand",
"first" => "eerste",
"second" => "tweede",
"third" => "derde",
"fourth" => "vierde",
"fifth" => "vijfde",
"last" => "laatste",
"by events date" => "volgens gebeurtenisdatum",
"by yearday(s)" => "volgens jaardag(en)",
"by weeknumber(s)" => "volgens weeknummer(s)",
"by day and month" => "per dag en maand",
"Contact birthdays" => "Verjaardagen contactpersonen",
"Date" => "Datum",
"Cal." => "Cal.",
"Day" => "Dag",
"Week" => "Week",
"Month" => "Maand",
"Today" => "Vandaag",
"CalDav Link" => "CalDav Link",
"Timezone" => "Tijdzone",
"Update timezone automatically" => "Werk de tijdzone automatisch bij",
"Time format" => "Tijd formaat",
"24h" => "24uur",
"12h" => "12uur",
"Start week on" => "Begin de week op",
"Cache" => "Cache",
"Clear cache for repeating events" => "Leeg cache voor repeterende gebeurtenissen",
"Primary CalDAV address" => "Primair CalDAV adres",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adres",
"Share Calendar" => "Deel kalender",
"Download" => "Download",
"Edit" => "Bewerken",
"Delete" => "Verwijderen",
"New calendar" => "Nieuwe agenda",
"Edit calendar" => "Bewerk agenda",
"Edit event" => "Bewerk gebeurtenis",
"Save event" => "Bewaar gebeurtenis",
"Delete event" => "Verwijder gebeurtenis",
"Eventinfo" => "Gebeurtenisinformatie",
"Repeating" => "Herhaling",
"Alarm" => "Alarm",
"Attendees" => "Deelnemers",
"Share" => "Delen",
"Title of the Event" => "Titel van de afspraak",
"from" => "van",
"to" => "naar",
"All Day Event" => "Hele dag",
"Advanced options" => "Geavanceerde opties",
"Location" => "Locatie",
"Categories (separate by comma)" => "Categorieën (commagescheiden)",
"Edit categories" => "Wijzig categorieën",
"Description" => "Beschrijving",
"Export event" => "Exporteer gebeurtenis",
"Repeat" => "Herhaling",
"Advanced" => "Geavanceerd",
"Select weekdays" => "Selecteer weekdagen",
"Select days" => "Selecteer dagen",
"and the events day of year." => "en de gebeurtenissen dag van het jaar",
"and the events day of month." => "en de gebeurtenissen dag van de maand",
"Select months" => "Selecteer maanden",
"Select weeks" => "Selecteer weken",
"and the events week of year." => "en de gebeurtenissen week van het jaar",
"Interval" => "Interval",
"End" => "Einde",
"occurrences" => "gebeurtenissen",
"Visibility to people shared with" => "Zichtbaar voor alle personen waarmee wordt gedeeld",
"create a new calendar" => "Maak een nieuw agenda",
"Import a calendar file" => "Importeer een agenda bestand",
"Please choose a calendar" => "Kies een agenda",
"Name of new calendar" => "Naam van de nieuwe agenda",
"Take an available name!" => "Kies een beschikbare naam!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Een agenda met deze naam bestaat al.  Als u doorgaat, worden deze agenda's samengevoegd",
"Remove all events from the selected calendar" => "Verwijder alle gebeurtenissen van de geselecteerde agenda",
"Import" => "Importeer",
"Close Dialog" => "Sluit venster",
"Create a new event" => "Maak een nieuwe afspraak",
"Create event" => "Creëer gebeurtenis",
"Share with user or group" => "Delen met gebruiker of groep",
"Unshare" => "Stop met delen",
"Not shared with anyone" => "Met niemand gedeeld",
"Send Email" => "Versturen e-mail",
"Shared via calendar" => "Gedeeld via agenda",
"Not shared with anyone via calendar" => "Niet met iemand gedeeld via de kalender",
"View an event" => "Bekijk een gebeurtenis",
"Category" => "Categorie",
"No categories selected" => "Geen categorieën geselecteerd",
"%s of %s" => "%s van %s",
"Access Class" => "Toegangsklasse",
"From" => "Van",
"at" => "op",
"To" => "Aan"
);
